DateInputValue typedef

DateInputValue = ({DateTime? parsedDate, String rawText})

The current state of a date input field, containing the parsed parsedDate (or null if invalid, incomplete, or out of range) and the rawText as typed.

Implementation

typedef DateInputValue = ({
  DateTime? parsedDate,
  String rawText,
});