MaterialDatePickerProvider class final
Shows a date picker using the Material UI library. This is primarily for Android and web platforms (other than Safari or a native iOS browser)
- Inheritance
-
- Object
- AdaptiveDatePickerProvider
- MaterialDatePickerProvider
Constructors
- MaterialDatePickerProvider()
- Creates a MaterialDatePickerProvider
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show(
{required BuildContext context, String? helpText, DateTime? initialDate, required DateTime firstDate, required DateTime lastDate}) → Future< DateTime?> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited