AdaptiveDatePickerProvider class abstract
A date picker provider that uses Cupertino styling in MacOS and iOS platforms, and Material styling in others
- Implementers
Constructors
- AdaptiveDatePickerProvider()
-
Creates an AdaptiveDatePickerProvider.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show(
{required BuildContext context, String? helpText, DateTime? initialDate, required DateTime firstDate, required DateTime lastDate}) → Future< DateTime?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited