DateInputFormatter class
Formats user date input dynamically based on the date format of the given locale.
- Inheritance
-
- Object
- TextInputFormatter
- DateInputFormatter
Constructors
- DateInputFormatter({String locale = 'en_GB'})
- Creates a DateInputFormatter configured for locale.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintText → String
-
Helper property to generate matching hint text (e.g. "DD/MM/YYYY", "MM/DD/YYYY", or "YYYY-MM-DD")
no setter
- locale → String
-
The locale string (e.g.
'en_GB','en_US') determining the date part ordering and separator.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
formatEditUpdate(
TextEditingValue oldValue, TextEditingValue newValue) → TextEditingValue -
Called when text is being typed or cut/copy/pasted in the EditableText.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited